/*

auto-eject

Script for automatically launching the player's escape pod if low on energy.


Oolite
Copyright © 2003-2013 Giles C Williams and contributors

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
MA 02110-1301, USA.


auto_eject.oxp
Copyright © 2010-2013 "Commander McLane"

This work is licensed under the Creative Commons
Attribution-Noncommercial-Share Alike 3.0 Unported License.

To view a copy of this license, visit
http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter
to Creative Commons, 171 Second Street, Suite 300, San Francisco,
California, 94105, USA.

*/


this.name           = "auto-eject";
this.description    = "Script for automatically launching the player's escape pod if low on energy."
this.author         = "Commander McLane";
this.copyright      = "© 2013 Commander McLane";
this.license		= "CC-by-nc-sa 3.0";
this.version        = "1.1";


/* event handlers */

this.shipTakingDamage = function()
{
	if(player.ship.energy < this.energyThreshold && this.autoEjectOn == 1)
	{
		if(player.ship.equipmentStatus("EQ_ESCAPE_POD") === "EQUIPMENT_OK" && player.ship.equipmentStatus("EQ_AUTO_EJECT") === "EQUIPMENT_OK")
		{
			player.consoleMessage("WARNING! Energy critically low! Auto Eject module activated.", 6);
			player.ship.abandonShip();
		}
		if(player.ship.equipmentStatus("EQ_ESCAPE_POD") === "EQUIPMENT_DAMAGED")
		{
			player.consoleMessage("WARNING! Energy critically low! Escape capsule off-line!", 6);
		}
		if(player.ship.equipmentStatus("EQ_AUTO_EJECT") === "EQUIPMENT_DAMAGED")
		{
			player.consoleMessage("WARNING! Energy critically low! Auto Eject module off-line!", 6);
		}
	}
}

this.shipLaunchedEscapePod = function()
{
    player.ship.removeEquipment("EQ_AUTO_EJECT");
    delete missionVariables.auto_eject_threshold;
    delete missionVariables.auto_eject_on;
}

this.playerBoughtEquipment = function(equipmentKey)
{
    if(equipmentKey === "EQ_AUTO_EJECT")
    {
        this.energyThreshold = 22;
        this.autoEjectOn = 1;
    }
    if(equipmentKey === "EQ_ESCAPE_POD_REMOVAL")
    {
        player.ship.removeEquipment("EQ_AUTO_EJECT");
        delete missionVariables.auto_eject_threshold;
        delete missionVariables.auto_eject_on;
    }
}

this.playerWillSaveGame = function()
{
    if(player.ship.equipmentStatus("EQ_AUTO_EJECT") === "EQUIPMENT_OK" || player.ship.equipmentStatus("EQ_AUTO_EJECT") === "EQUIPMENT_DAMAGED")
    {
        missionVariables.auto_eject_on = this.autoEjectOn;
        missionVariables.auto_eject_threshold = this.energyThreshold;
    }
}

this.startUp = function()
{
    if(player.ship.equipmentStatus("EQ_AUTO_EJECT") === "EQUIPMENT_OK" || player.ship.equipmentStatus("EQ_AUTO_EJECT") === "EQUIPMENT_DAMAGED")
    {
        if(missionVariables.auto_eject_on)
        {
            this.autoEjectOn = missionVariables.auto_eject_on;
        }
        else
        {
            this.autoEjectOn = 1;
        }
        if(missionVariables.auto_eject_threshold)
        {
            this.energyThreshold = missionVariables.auto_eject_threshold;
        }
        else
        {
            this.energyThreshold = 22;
        }
    }
    delete this.startup;
}
